
===============================
Generative Adversarial Networks
===============================

Papers
------

* [14.06] `Generative adversarial nets <https://arxiv.org/abs/1406.2661>`_
* [14.11] `Learning to generate chairs with convolutional neural networks <https://arxiv.org/abs/1411.5928>`_
* [15.06] `Deep Generative Image Models using a￼ Laplacian Pyramid of Adversarial Networks <https://arxiv.org/abs/1506.05751>`_
* [15.11] `Unsupervised representation learning with deep convolutional generative adversarial networks <https://arxiv.org/abs/1511.06434>`_
* [15.11] `Deep multi-scale video prediction beyond mean square error <https://arxiv.org/abs/1511.05440>`_
* [16.02] `Generating images with recurrent adversarial networks <https://arxiv.org/abs/1602.05110>`_
* [16.06] `Improved Techniques for Training GANs <https://arxiv.org/abs/1606.03498>`_
* [16.06] `InfoGAN: Interpretable Representation Learning by Information Maximizing Generative Adversarial Nets <https://arxiv.org/abs/1606.03657>`_
* [16.09] `SeqGAN: Sequence Generative Adversarial Nets with Policy Gradient <https://arxiv.org/abs/1609.05473>`_
* [16.10] `Conditional Image Synthesis With Auxiliary Classifier GANs <https://arxiv.org/abs/1610.09585>`_
